@@ -33,8 +33,6 @@ warnings.formatwarning = warning_on_one_line
 # ---------------- Class definition for experiments -----------
 
 class exper:
-  io_2use = {'default':'check_file','S':'dlmread'}
-  plot_2use = {'S':'plot'}
   
   def __repr__(self):
     return self.name
@@ -215,15 +213,14 @@ class exper:
 
 
       
-  def load(self,varnames, filename = None, squeeze_field = True, ax=None, name_suffix='_cat', new_coord_name = 'gamma', new_coord= None ):
+  def load(self,varnames, squeeze_field = True, ax=None, name_suffix='_cat', new_coord_name = 'gamma', new_coord= None ):
     """
     Field load method of exper class.
 
-    Load a variable or list of variables contained in varnames. Takes either a single string or a list of strings. If no filename argument is given, all Netcdf files in the experiment directory will be examined. If multiple files inside a directory contain the same variable, this method will attempt to concatenate them (e.g. in the case where there are different time slices).
+    Load a variable or list of variables contained in varnames. Takes either a single string or a list of strings. If multiple files inside a directory contain the same variable, this method will attempt to concatenate them (e.g. in the case where there are different time slices).
 
     Inputs:
     varnames		list of the variable names to load
-    filename		redundant legacy
     squeeze_field	switch to squeeze field on loading (default True)	
 
     The following arguments are passed on to the concatenate function:
@@ -237,8 +234,6 @@ class exper:
 
     """  
 
-    # filename legacy argument!!!
-
 # --> this load is a method of class exper
 
     if not(isinstance(varnames, list)):
